package types

import (
	"time"

	"gorm.io/gorm"
)

type (

	// sql options
	SqlOptions struct {
		MaxIdleConns    int `gorm:"column:max_idle_conns;"  json:"max_idle_conns"`
		MaxOpenConns    int `gorm:"column:max_open_conns;"  json:"max_open_conns"`
		ConnMaxLifetime time.Duration

		LogStdout bool `gorm:"column:log_stdout;"  json:"log_stdout"`
		Debug     bool `gorm:"column:debug;"  json:"debug"`
	}

	// standard ID,Identity definition.
	Std_IDIdentity struct {
		ID       uint   `gorm:"column:id;primarykey;"  json:"id"`
		Identity string `gorm:"column:identity;type:varchar(36);uniqueIndex;"  json:"identity"` // 唯一标识，24位NanoID,36位为ULID
	}

	// standard ID,Created,Updated,Deleted definition.
	Std_IICUDS struct {
		ID        uint           `gorm:"column:id;primarykey;"  json:"id"`
		Identity  string         `gorm:"column:identity;type:varchar(36);uniqueIndex;"  json:"identity"` // 唯一标识，24位NanoID,36位为ULID
		CreatedAt time.Time      `gorm:"column:created_at;" json:"created_at"`
		UpdatedAt time.Time      `gorm:"column:updated_at;" json:"updated_at"`
		DeletedAt gorm.DeletedAt `gorm:"column:deleted_at;index;" json:"deleted_at"`
		Status    int8           `gorm:"column:status;default:0;index;" json:"status"` // 状态：默认为0，-1禁止，1为正常
	}

	// standard ID,Identity,Created,Updated,Deleted,Status definition.
	Std_ICUD struct {
		ID        uint           `gorm:"column:id;primarykey;"  json:"id"`
		CreatedAt time.Time      `gorm:"column:created_at;" json:"created_at"`
		UpdatedAt time.Time      `gorm:"column:updated_at;" json:"updated_at"`
		DeletedAt gorm.DeletedAt `gorm:"column:deleted_at;index;" json:"deleted_at"`
	}

	// standard ID,Created definition.
	Std_IdCreated struct {
		ID        uint      `gorm:"column:id;primarykey;"  json:"id"`
		CreatedAt time.Time `gorm:"column:created_at;" json:"created_at"`
	}

	// standard PassportID,PassportIdentity definition.
	Std_Passport struct {
		PassportID       uint   `gorm:"column:passport_id;Index;" json:"passport_id"`
		PassportIdentity string `gorm:"column:passport_identity;type:varchar(36);Index;"  json:"passport_identity"` // 用户唯一标识，24位NanoID,36位为UUID
	}

	// standard OwnerID,OwnerIdentity definition.
	Std_Owner struct {
		OwnerID       uint   `gorm:"column:owner_id;Index;" json:"owner_id"`
		OwnerIdentity string `gorm:"column:owner_identity;type:varchar(36);Index;"  json:"owner_identity"` // 用户唯一标识，24位NanoID,36位为UUID
	}

	// standard ID definition.
	Std_ID struct {
		ID uint `gorm:"column:id;primarykey;"  json:"id"`
	}

	// standard Identity definition.
	Std_Identity struct {
		Identity string `gorm:"column:identity;type:varchar(36);uniqueIndex;"  json:"identity"` // 唯一标识，24位NanoID,36位为UUID
	}

	// standard Status definition.
	Std_Status struct {
		Status int64 `gorm:"column:status;default:0;index;" json:"status"` // 状态：默认为0，-1禁止，1为正常
	}
)
